@@ -1,5 +1,8 @@
 package MARC::Charset::Ansel;
 
+use MARC::Charset::Generic qw( :all );
+use base qw( MARC::Charset::Generic );
+
 =head1 NAME
 
 MARC::Charset::Ansel - MARC8/UTF8 mappings for Ansel
@@ -13,14 +16,15 @@ MARC::Charset::Ansel - MARC8/UTF8 mappings for Ansel
 
 MARC::Charset::Ansel provides a mapping between the MARC8 Ansel character
 set and Unicode(UTF8). It is typically used by MARC::Charset, so you 
-probably don't need to use this yourself. 
+probably don't need to use this yourself. It inherits from
+MARC::Charset::Generic so you'll have to look at those docs to see all the
+methods that you can call.
 
 =head1 METHODS
 
 =cut 
 
 use strict;
-use constant CHAR_SIZE	    => 1;
 our %marc2unicode;
 our %combining;
 
@@ -33,17 +37,12 @@ The constructor, which will return you a MARC::Charset::Ansel object.
 
 sub new {
     my $class = shift;
-    return bless {}, ref($class) || $class;
-}
-
-=head1 name()
-
-Returns the name of the character set.
-
-=cut
-
-sub name {
-    return('Ansel');
+    return bless 
+	{
+	    NAME	=> 'Ansel',
+	    CHARSETCODE	=> EXTENDED_LATIN, 
+	    CHARSIZE	=> 1
+	}, ref($class) || $class;
 }
 
 =head1 lookup()
@@ -72,17 +71,6 @@ sub combining {
     return( $combining{$char} );
 }
 
-=head1 getCharSize()
-
-Returns the number of bytes in each character of this character set.
-
-=cut
-
-
-sub getCharSize {
-    return(CHAR_SIZE);
-}
-
 %marc2unicode = (
 
 chr(0xA1)=>chr(0x0141), # UPPERCASE POLISH L / LATIN CAPITAL L WITH STROKE
@@ -193,6 +181,14 @@ chr(0xFE) => 1, # HIGH COMMA, CENTERED / COMBINING COMMA ABOVE (Psili)
 
 =back
 
+=head1 SEE ALSO
+
+=over 4
+
+=item MARC::Charset::Generic
+
+=back
+
 =head1 AUTHORS
 
 =over 4
