@@ -1,5 +1,8 @@
 package MARC::Charset::Controls;
 
+use MARC::Charset::Generic qw( :all );
+use base qw( MARC::Charset::Generic );
+
 =head1 NAME
 
 MARC::Charset::Controls - A MARC8/UTF8 mapping for MARC8 Control Characters
@@ -13,14 +16,15 @@ MARC::Charset::Controls - A MARC8/UTF8 mapping for MARC8 Control Characters
 
 MARC::Charset::Controls provides a mapping between the MARC8 control character
 set and Unicode(UTF8). It is typically used by MARC::Charset, so you 
-probably don't need to use this yourself. 
+probably don't need to use this yourself. It inherits from
+MARC::Charset::Generic so you'll need to look at those docs to get an idea of
+all the methods you can call.
 
 =head1 METHODS
 
 =cut 
 
 use strict;
-use constant CHAR_SIZE	    => 1;
 our %marc2unicode;
 
 =head1 
@@ -32,18 +36,12 @@ The constructor, which will return you a MARC::Charset::Controls object.
 
 sub new {
     my $class = shift;
-    return bless {}, ref($class) || $class;
-}
-
-=head1 name()
-
-Returns the name of the character set.
-
-=cut
-
-
-sub name {
-    return('Controls');
+    return bless 
+	{
+	    NAME	=> 'Controls',
+	    CHARSETCODE	=> undef,
+	    CHARSIZE	=> 1
+	}, ref($class) || $class;
 }
 
 =head1 lookup()
@@ -53,7 +51,6 @@ get back the UTF8 character.
 
 =cut
 
-
 sub lookup {
     my ($self,$char) = @_; 
     return($marc2unicode{$char});
@@ -71,17 +68,6 @@ sub combining {
     return(undef); ## no combining chars
 }
 
-=head1 getCharSize()
-
-Returns the number of bytes in each character of this character set.
-
-=cut
-
-
-sub getCharSize {
-    return(CHAR_SIZE);
-}
-
 %marc2unicode = (
 
 chr(0x1B)=>chr(0x001B), # ESCAPE (Unlikely to occur in UCS/Unicode)
@@ -100,7 +86,15 @@ chr(0x8E)=>chr(0x200C), # NON-JOINER / ZERO WIDTH NON-JOINER
 
 =over 4 
 
-=item *
+=item Nothing
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item MARC::Charset::Generic
 
 =back
 
