@@ -1,5 +1,8 @@
 package MARC::Charset::CyrillicBasic;
 
+use MARC::Charset::Generic qw( :all );
+use base qw( MARC::Charset::Generic );
+
 =head1 NAME
 
 MARC::Charset::CyrillicBasic - MARC8/UTF8 encodings for Basic Cyrillic.
@@ -13,15 +16,16 @@ MARC::Charset::CyrillicBasic - MARC8/UTF8 encodings for Basic Cyrillic.
 
 MARC::Charset::ASCII provides a mapping between the MARC8 basic Cyrillic 
 character set and Unicode(UTF8). It is typically used by MARC::Charset, so 
-you probably don't need to use this yourself. 
+you probably don't need to use this yourself. It inherits from
+MARC::Charset::Generic so look at those docs to see all the methods you can
+call.
 
 =head1 METHODS
 
 =cut 
 
 use strict;
-use constant CHAR_SIZE	    => 1;
-my %marc2unicode;
+our %marc2unicode;
 
 =head1 
 
@@ -31,18 +35,12 @@ The constructor, which will return you a MARC::Charset::CyrillicBasic object.
 
 sub new {
     my $class = shift;
-    return bless {}, ref($class) || $class;
-}
-
-=head1 name()
-
-Returns the name of the character set.
-
-=cut
-
-
-sub name {
-    return('Cyrillic-Basic');
+    return bless 
+	{
+	    NAME	=> 'Cyrillic-Basic',
+	    CHARSETCODE	=> BASIC_CYRILLIC,
+	    CHARSIZE	=> 1
+	}, ref($class) || $class;
 }
 
 =head1 lookup()
@@ -70,17 +68,6 @@ sub combining {
     return(undef); ## aren't any
 }
 
-=head1 getCharSize()
-
-Returns the number of bytes in each character of this character set.
-
-=cut
-
-
-sub getCharSize {
-    return(CHAR_SIZE);
-}
-
 %marc2unicode = (
 
 chr(0x21)=>chr(0x0021), #EXCLAMATION MARK
@@ -184,7 +171,15 @@ chr(0x7E)=>chr(0x0427), #CYRILLIC CAPITAL LETTER CHE
 
 =over 4 
 
-=item *
+=item Nothing.
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item MARC::Charset::Generic
 
 =back
 
