@@ -1,5 +1,8 @@
 package MARC::Charset::CyrillicExtended;
 
+use MARC::Charset::Generic qw( :all );
+use base qw( MARC::Charset::Generic );
+
 =head1 NAME
 
 MARC::Charset::CyrillicExtended - MARC8/UTF8 mappings for Extended Cyrillic
@@ -13,15 +16,16 @@ MARC::Charset::CyrillicExtended - MARC8/UTF8 mappings for Extended Cyrillic
 
 MARC::Charset::CyrillicExtented provides a mapping between the MARC8 Extended
 Cyrillic character set and Unicode(UTF8). It is typically used by 
-MARC::Charset, so you probably don't need to use this yourself. 
+MARC::Charset, so you probably don't need to use this yourself. It inherits from
+MARC::Charset::Generic, so you'll need to look at those docs to see all of the 
+methods you can call.
 
 =head1 METHODS
 
 =cut 
 
 use strict;
-use constant CHAR_SIZE	    => 1;
-my %marc2unicode;
+our %marc2unicode;
 
 =head1 
 
@@ -32,18 +36,12 @@ The constructor, which will return you a MARC::Charset::CyrillicExtended object.
 
 sub new {
     my $class = shift;
-    return bless {}, ref($class) || $class;
-}
-
-=head1 name()
-
-Returns the name of the character set.
-
-=cut
-
-
-sub name {
-    return('Cyrillic-Extended');
+    return bless 
+	{
+	    NAME	=> 'Cyrillic-Extended',
+	    CHARSETCODE	=> EXTENDED_CYRILLIC,
+	    CHARSIZE	=> 1
+	}, ref($class) || $class;
 }
 
 =head1 lookup()
@@ -53,7 +51,6 @@ get back the UTF8 character.
 
 =cut
 
-
 sub lookup {
     my ($self,$char) = @_; 
     return($marc2unicode{$char});
@@ -66,22 +63,10 @@ a combining character, and false (undef) if it is not.
 
 =cut
 
-
 sub combining {
     return(undef); ## aren't any
 }
 
-=head1 getCharSize()
-
-Returns the number of bytes in each character of this character set.
-
-=cut
-
-
-sub getCharSize {
-    return(CHAR_SIZE);
-}
-
 %marc2unicode = (
     
 chr(0xC0)=>chr(0x0491), #LOWER GE WITH UPTURN / CYR SM LETTER GHE WITH UPTURN
@@ -133,7 +118,15 @@ chr(0xF3)=>chr(0x046A), #CYRILLIC CAPITAL LETTER BIG YUS
 
 =over 4 
 
-=item *
+=item Nothing.
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item MARC::Charset::Generic
 
 =back
 
