@@ -1,5 +1,8 @@
 package MARC::Charset::GreekSymbols;
 
+use MARC::Charset::Generic qw( :all );
+use base qw( MARC::Charset::Generic );
+
 =head1 NAME
 
 MARC::Charset::GreekSymbols - MARC8/UTF8 character encodings for Greek Symbols
@@ -13,15 +16,15 @@ MARC::Charset::GreekSymbols - MARC8/UTF8 character encodings for Greek Symbols
 
 MARC::Charset::GreekSymbols provides a mapping between the MARC8 Greek Symbol 
 character set and Unicode(UTF8). It is typically used by MARC::Charset, so you 
-probably don't need to use this yourself. 
+probably don't need to use this yourself. It inherits from
+MARC::Charset::Generic, so look at those docs to see all the available methods.
 
 =head1 METHODS
 
 =cut 
 
 use strict;
-use constant CHAR_SIZE	    => 1;
-my %marc2unicode;
+our %marc2unicode;
 
 =head1 
 
@@ -32,18 +35,13 @@ The constructor, which will return you a MARC::Charset::GreekSymbols object.
 
 sub new {
     my $class = shift;
-    return bless {}, ref($class) || $class;
-}
+    return bless 
+	{
+	    NAME	=> 'Greek-Symbols',
+	    CHARSETCODE	=> GREEK_SYMBOLS,
+	    CHARSIZE	=> 1,
 
-=head1 name()
-
-Returns the name of the character set.
-
-=cut
-
-
-sub name {
-    return('Greek-Symbols');
+	}, ref($class) || $class;
 }
 
 =head1 lookup()
@@ -53,7 +51,6 @@ get back the UTF8 character.
 
 =cut
 
-
 sub lookup {
     my ($self,$char) = @_; 
     return($marc2unicode{$char});
@@ -66,22 +63,10 @@ a combining character, and false (undef) if it is not.
 
 =cut
 
-
 sub combining {
     return(undef); ## aren't any
 }
 
-=head1 getCharSize()
-
-Returns the number of bytes in each character of this character set.
-
-=cut
-
-
-sub getCharSize {
-    return(CHAR_SIZE);
-}
-
 %marc2unicode = (
 
 chr(0x61)=>chr(0x03B1),  #GREEK SMALL LETTER ALPHA
@@ -94,7 +79,15 @@ chr(0x63)=>chr(0x03B3),  #GREEK SMALL LETTER GAMMA
 
 =over 4 
 
-=item *
+=item Nothing
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item MARC::Charset::Generic
 
 =back
 
