@@ -1,5 +1,8 @@
 package MARC::Charset::Hebrew;
 
+use MARC::Charset::Generic qw( :all );
+use base qw( MARC::Charset::Generic );
+
 =head1 NAME
 
 MARC::Charset::Hebrew - MARC8/UTF8 mappings for Hebrew
@@ -13,15 +16,17 @@ MARC::Charset::Hebrew - MARC8/UTF8 mappings for Hebrew
 
 MARC::Charset::Hebrew provides a mapping between the MARC8 Hebrew character
 set and Unicode(UTF8). It is typically used by MARC::Charset, so you 
-probably don't need to use this yourself. 
+probably don't need to use this yourself. It inherits from
+MARC::Charset::Generic so look at those docs to see all the methods that are
+available.
 
 =head1 METHODS
 
 =cut 
 
 use strict;
-use constant CHAR_SIZE	    => 1;
-my (%marc2unicode,%combining);
+our %marc2unicode;
+our %combining;
 
 =head1 
 
@@ -32,18 +37,12 @@ The constructor, which will return you a MARC::Charset::Hebrew object.
 
 sub new {
     my $class = shift;
-    return bless {}, ref($class) || $class;
-}
-
-=head1 name()
-
-Returns the name of the character set.
-
-=cut
-
-
-sub name {
-    return('Hebrew');
+    return bless 
+	{
+	    NAME	=> 'Hebrew',
+	    CHARSETCODE	=> BASIC_HEBREW,
+	    CHARSIZE	=> 1
+	}, ref($class) || $class;
 }
 
 =head1 lookup()
@@ -53,7 +52,6 @@ get back the UTF8 character.
 
 =cut
 
-
 sub lookup {
     my ($self,$char) = @_; 
     return($marc2unicode{$char});
@@ -66,23 +64,10 @@ a combining character, and false (undef) if it is not.
 
 =cut
 
-
 sub combining {
     return(undef); ## none???
 }
 
-=head1 getCharSize()
-
-Returns the number of bytes in each character of this character set.
-
-=cut
-
-
-sub getCharSize {
-    return(CHAR_SIZE);
-}
-
-
 %marc2unicode = (
 
 chr(0x21)=>chr(0x0021), #EXCLAMATION MARK
@@ -120,7 +105,7 @@ chr(0x40)=>chr(0x05B7), #HEBREW POINT PATAH
 chr(0x41)=>chr(0x05B8), #KAMATS / HEBREW POINT QAMATS
 chr(0x42)=>chr(0x05B6), #HEBREW POINT SEGOL
 chr(0x43)=>chr(0x05B5), #TSEREH / HEBREW POINT TSERE
-chr(0x45)=>chr(0x05B4), #HIRIK / HEBREW POINT HIRIQ
+chr(0x44)=>chr(0x05B4), #HIRIK / HEBREW POINT HIRIQ
 chr(0x45)=>chr(0x05B9), #HOLAM, LEFT SIN DOT / HEBREW POINT HOLAM
 chr(0x46)=>chr(0x05BB), #KUBUTS / HEBREW POINT QUBUTS
 chr(0x47)=>chr(0x05B0), #HEBREW POINT SHEVA
@@ -173,7 +158,15 @@ chr(0x7D)=>chr(0x05F2), #HEBREW LIGATURE YIDDISH DOUBLE YOD / TSVEY YUDN
 
 =over 4 
 
-=item *
+=item Are some of these combining characters?
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item MARC::Charset::Generic
 
 =back
 
