@@ -1,5 +1,8 @@
 package MARC::Charset::Subscripts;
 
+use MARC::Charset::Generic qw( :all );
+use base qw( MARC::Charset::Generic );
+
 =head1 NAME
 
 MARC::Charset::Subscripts - MARC8/UTF8 mapping for Subscripts
@@ -13,15 +16,15 @@ MARC::Charset::Subscripts - MARC8/UTF8 mapping for Subscripts
 
 MARC::Charset::Subscripts provides a mapping between the MARC8 Subscript 
 character set and Unicode(UTF8). It is typically used by MARC::Charset, so you 
-probably don't need to use this yourself. 
+probably don't need to use this yourself. It inherits from
+MARC::Charset::Generic so look at those docs to see all the available methods.
 
 =head1 METHODS
 
 =cut 
 
 use strict;
-use constant CHAR_SIZE	    => 1;
-my %marc2unicode;
+our %marc2unicode;
 
 =head1 
 
@@ -29,21 +32,14 @@ The constructor, which will return you a MARC::Charset::Subscripts object.
 
 =cut
 
-
 sub new {
     my $class = shift;
-    return bless {}, ref($class) || $class;
-}
-
-=head1 name()
-
-Returns the name of the character set.
-
-=cut
-
-
-sub name {
-    return('Subscripts');
+    return bless 
+	{
+	    NAME	=> 'Subscripts',
+	    CHARSETCODE => SUBSCRIPTS,
+	    CHARSIZE	=> 1
+	}, ref($class) || $class;
 }
 
 =head1 lookup()
@@ -53,7 +49,6 @@ get back the UTF8 character.
 
 =cut
 
-
 sub lookup {
     my ($self,$char) = @_; 
     return($marc2unicode{$char});
@@ -66,23 +61,10 @@ a combining character, and false (undef) if it is not.
 
 =cut
 
-
 sub combining {
     return(undef); ## no combining chars
 }
 
-=head1 getCharSize()
-
-Returns the number of bytes in each character of this character set.
-
-=cut
-
-
-sub getCharSize {
-    return(CHAR_SIZE);
-}
-
-
 %marc2unicode = (
 
 chr(0x28)=>chr(0x208D),  #SUBSCRIPT OPENING PAREN / SUBSCRIPT LEFT PARENTHESIS
@@ -106,7 +88,15 @@ chr(0x39)=>chr(0x2089),  #SUBSCRIPT DIGIT NINE
 
 =over 4 
 
-=item *
+=item Nothing.
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item MARC::Charset::Generic
 
 =back
 
