@@ -1,5 +1,8 @@
 package MARC::Charset::Superscripts;
 
+use MARC::Charset::Generic qw( :all );
+use base qw( MARC::Charset::Generic );
+
 =head1 NAME
 
 MARC::Charset::Superscripts - MARC8/UTF8 mapping for Superscripts
@@ -13,15 +16,15 @@ MARC::Charset::Superscripts - MARC8/UTF8 mapping for Superscripts
 
 MARC::Charset::Superscripts provides a mapping between the MARC8 Superscript 
 character set and Unicode(UTF8). It is typically used by MARC::Charset, so 
-you probably don't need to use this yourself. 
+you probably don't need to use this yourself. It inherits from
+MARC::Charset::Generic so look at those docs to see all available methods.
 
 =head1 METHODS
 
 =cut 
 
 use strict;
-use constant CHAR_SIZE	    => 1;
-my %marc2unicode;
+our %marc2unicode;
 
 =head1 
 
@@ -32,18 +35,12 @@ The constructor, which will return you a MARC::Charset::Superscript object.
 
 sub new {
     my $class = shift;
-    return bless {}, ref($class) || $class;
-}
-
-=head1 name()
-
-Returns the name of the character set.
-
-=cut
-
-
-sub name {
-    return('Superscripts');
+    return bless 
+	{
+	    NAME	=> 'Superscripts',
+	    CHARSETCODE	=> SUPERSCRIPTS,
+	    CHARSIZE	=> 1
+	}, ref($class) || $class;
 }
 
 =head1 lookup()
@@ -53,7 +50,6 @@ get back the UTF8 character.
 
 =cut
 
-
 sub lookup {
     my ($self,$char) = @_; 
     return($marc2unicode{$char}); 
@@ -70,17 +66,6 @@ sub combining {
     return(undef);
 }
 
-=head1 getCharSize()
-
-Returns the number of bytes in each character of this character set.
-
-=cut
-
-
-sub getCharSize {
-    return(CHAR_SIZE);
-}
-
 %marc2unicode = (
 
 chr(0x28)=>chr(0x207D), #SUPERSCRIPT OPENING PAREN / SUPERSCRIPT LEFT PAREN
@@ -104,7 +89,15 @@ chr(0x39)=>chr(0x2079), #SUPERSCRIPT DIGIT NINE
 
 =over 4 
 
-=item *
+=item Nothing
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item MARC::Charset::Generic
 
 =back
 
